@@ -4,6 +4,8 @@ UBX Protocol core globals and constants
 
 Created on 27 Sep 2020
 
+Information sourced from u-blox Interface Specifications © 2013-2021, u-blox AG
+
 :author: semuadmin
 """
 
@@ -27,6 +29,7 @@ GNSSLIST = {
 # **************************************************
 # THESE ARE THE UBX PROTOCOL PAYLOAD ATTRIBUTE TYPES
 # **************************************************
+A256 = "A256"  # Array of bytes (only currently used for MON-SPAN spectrum)
 C2 = "C002"  # ASCII / ISO 8859.1 Encoding 2 bytes
 C6 = "C006"  # ASCII / ISO 8859.1 Encoding 6 bytes
 C10 = "C010"  # ASCII / ISO 8859.1 Encoding 10 bytes
@@ -51,6 +54,7 @@ U7 = "U007"  # Unsigned Int 7 bytes
 U8 = "U008"  # Unsigned Int 8 bytes
 U9 = "U009"  # Unsigned Int 9 bytes
 U12 = "U012"  # Unsigned Int 12 bytes
+U22 = "U022"  # Unsigned Int 22 bytes
 U40 = "U040"  # Unsigned Int 40 bytes
 U64 = "U064"  # Unsigned Int 64 bytes
 X1 = "X001"  # Bitfield 1 byte
@@ -62,6 +66,7 @@ R4 = "R004"  # Float (IEEE 754) Single Precision 4 bytes
 R8 = "R008"  # Float (IEEE 754) Double Precision 8 bytes
 
 VALID_TYPES = (
+    A256,
     C2,
     C6,
     C10,
@@ -88,6 +93,7 @@ VALID_TYPES = (
     U8,
     U9,
     U12,
+    U22,
     U40,
     U64,
     X1,
